Branch

Enum Branch 

pub enum Branch {
    Local {
        name: String,
        committer_email: String,
        committer_date_time: DateTime<Utc>,
    },
    Remote {
        name: String,
        committer_email: String,
        committer_date_time: DateTime<Utc>,
    },
}
Local or remote branch with metadata about the last commit.

Variants



Local

Local branch (under refs/heads/).

Fields

name: String

The name of the branch (without refs/heads/ or refs/remotes/ prefix).

committer_email: String

The email address of the last committer.

committer_date_time: DateTime<Utc>

The date and time when the last commit was made.



Remote

Remote tracking branch (under refs/remotes/).

Fields

name: String

The name of the branch (without refs/heads/ or refs/remotes/ prefix).

committer_email: String

The email address of the last committer.

committer_date_time: DateTime<Utc>

The date and time when the last commit was made.

Implementations

Source

impl Branch

pub fn name(&self) -> &str

Returns the branch name (no “refs/” prefix).

pub fn name_no_origin(&self) -> &str

Returns the branch name with the “origin/” prefix removed if present.

pub fn committer_email(&self) -> &str

Returns the email address of the last committer on this branch.

pub const fn committer_date_time(&self) -> &DateTime<Utc>

Returns the timestamp of the last commit on this branch.