pub enum Branch {
Local {
name: String,
committer_email: String,
committer_date_time: DateTime<Utc>,
},
Remote {
name: String,
committer_email: String,
committer_date_time: DateTime<Utc>,
},
}Expand description
Local or remote branch with metadata about the last commit.
Variants
Implementations
Sourceimpl Branch
impl Branch
Sourcepub fn name_no_origin(&self) -> &str
pub fn name_no_origin(&self) -> &str
Returns the branch name with the “origin/” prefix removed if present.
Sourcepub fn committer_email(&self) -> &str
pub fn committer_email(&self) -> &str
Returns the email address of the last committer on this branch.
Sourcepub const fn committer_date_time(&self) -> &DateTime<Utc>
pub const fn committer_date_time(&self) -> &DateTime<Utc>
Returns the timestamp of the last commit on this branch.